@@ -7,10 +7,15 @@ from selenium.webdriver.chrome.options import Options
 from webdriver_manager.chrome import ChromeDriverManager
 from selenium.webdriver.support.ui import Select
 
+
 def remove_none(L):
     return [x for x in L if x is not None]
 
 
+def delhi_HC_scraper():
+    return delhi_hc_search()
+
+
 class delhi_hc_search:
     def __init__(self, case_type, case_year, case_no=None, headless=True, no_image=True, delay=1, ret=False):
         """
